@@ -7,12 +7,12 @@
 # Distributed under terms of the GPLv3+ license.
 
 """
-    Slixmpp OMEMO plugin
-    Copyright © 2019 Maxime “pep” Buquet <pep@bouah.net>
+    Poezio OMEMO plugin
+    Copyright © 2021 Maxime “pep” Buquet <pep@bouah.net>
     This file is part of poezio-omemo.
 
     See the file LICENSE for copying permission.
 """
 
-__version__ = "0.4.0"
-__version_info__ = (0, 4, 0)
+__version__ = "0.4.1"
+__version_info__ = (0, 4, 1)
